setGlobalParameter method
void
setGlobalParameter({
- PlaceholderWidgetBuilder? globalPlaceholderWidget,
- LoadingErrorWidgetBuilder? globalErrorWidget,
Sets the global parameters for placeholder and error widgets.
globalPlaceholderWidget is the widget displayed while an image is loading.
globalErrorWidget is the widget displayed if an error occurs while loading an image.
Implementation
void setGlobalParameter({
PlaceholderWidgetBuilder? globalPlaceholderWidget,
LoadingErrorWidgetBuilder? globalErrorWidget,
}) {
globalPlaceholder = globalPlaceholderWidget;
globalError = globalErrorWidget;
}